==> node-typescript_2.0.8.orig.tar.gz: TypeScript-2.0.8/tests/baselines/reference/duplicateAnonymousModuleClasses.js <==
//// [duplicateAnonymousModuleClasses.ts]
module F {

    class Helper {

    }

}


module F {
    
    // Should not be an error
    class Helper {

    }

}

module Foo {

    class Helper {

    }

}


module Foo {
    
    // Should not be an error
    class Helper {

    }

}

module Gar {
    module Foo {

        class Helper {

        }

    }


    module Foo {
    
        // Should not be an error
        class Helper {

        }

    }
}


//// [duplicateAnonymousModuleClasses.js]
var F;
(function (F) {
    var Helper = (function () {
        function Helper() {
        }
        return Helper;
    }());
})(F || (F = {}));
var F;
(function (F) {
    // Should not be an error
    var Helper = (function () {
        function Helper() {
        }
        return Helper;
    }());
})(F || (F = {}));
var Foo;
(function (Foo) {
    var Helper = (function () {
        function Helper() {
        }
        return Helper;
    }());
})(Foo || (Foo = {}));
var Foo;
(function (Foo) {
    // Should not be an error
    var Helper = (function () {
        function Helper() {
        }
        return Helper;
    }());
})(Foo || (Foo = {}));
var Gar;
(function (Gar) {
    var Foo;
    (function (Foo) {
        var Helper = (function () {
            function Helper() {
            }
            return Helper;
        }());
    })(Foo || (Foo = {}));
    var Foo;
    (function (Foo) {
        // Should not be an error
        var Helper = (function () {
            function Helper() {
            }
            return Helper;
        }());
    })(Foo || (Foo = {}));
})(Gar || (Gar = {}));

==> node-typescript_4.0.3.orig.tar.gz: TypeScript-4.0.3/tests/baselines/reference/duplicateAnonymousModuleClasses.js <==
//// [duplicateAnonymousModuleClasses.ts]
module F {

    class Helper {

    }

}


module F {
    
    // Should not be an error
    class Helper {

    }

}

module Foo {

    class Helper {

    }

}


module Foo {
    
    // Should not be an error
    class Helper {

    }

}

module Gar {
    module Foo {

        class Helper {

        }

    }


    module Foo {
    
        // Should not be an error
        class Helper {

        }

    }
}


//// [duplicateAnonymousModuleClasses.js]
var F;
(function (F) {
    var Helper = /** @class */ (function () {
        function Helper() {
        }
        return Helper;
    }());
})(F || (F = {}));
(function (F) {
    // Should not be an error
    var Helper = /** @class */ (function () {
        function Helper() {
        }
        return Helper;
    }());
})(F || (F = {}));
var Foo;
(function (Foo) {
    var Helper = /** @class */ (function () {
        function Helper() {
        }
        return Helper;
    }());
})(Foo || (Foo = {}));
(function (Foo) {
    // Should not be an error
    var Helper = /** @class */ (function () {
        function Helper() {
        }
        return Helper;
    }());
})(Foo || (Foo = {}));
var Gar;
(function (Gar) {
    var Foo;
    (function (Foo) {
        var Helper = /** @class */ (function () {
            function Helper() {
            }
            return Helper;
        }());
    })(Foo || (Foo = {}));
    (function (Foo) {
        // Should not be an error
        var Helper = /** @class */ (function () {
            function Helper() {
            }
            return Helper;
        }());
    })(Foo || (Foo = {}));
})(Gar || (Gar = {}));
